@@ -6,10 +6,20 @@ import os
 
 # fmt: off
 __project__ = 'pfxbrick'
-__version__ = '0.8.4'
+__version__ = '0.8.5'
+
+# API version
 
 VERSION = __project__ + "-" + __version__
 
+# ICD version this API is compliant with
+#   for more detail, consult:
+#   https://www.fxbricks.com/downloads/PFxBrickICD-Rev3.39.pdf
+#   and
+#   https://github.com/fx-bricks/pfx-brick-dev
+
+ICD_REV = '3.39'
+
 script_dir = os.path.dirname(__file__)
 
 from .pfx import *
